@@ -1,5 +1,5 @@
 // CALCIT VERSION
-export const calcit_version = "0.4.21";
+export const calcit_version = "0.4.24";
 
 import { overwriteComparator, initTernaryTreeMap } from "@calcit/ternary-tree";
 import { parse } from "@cirru/parser.ts";
@@ -934,6 +934,11 @@ export let get_char_code = (c: string): number => {
   return c.charCodeAt(0);
 };
 
+export let char_from_code = (n: number): string => {
+  if (typeof n !== "number") throw new Error("Expected na integer");
+  return String.fromCharCode(n);
+};
+
 export let re_matches = (content: string, re: string): boolean => {
   return new RegExp(re).test(content);
 };
@@ -1454,6 +1459,10 @@ export let _$n_list_$o_distinct = (xs: CalcitList): CalcitList => {
   return new CalcitList(result);
 };
 
+export let _$n_get_os = (): CalcitKeyword => {
+  return kwd("js-engine");
+};
+
 // special procs have to be defined manually
 export let reduce = foldl;
 
